@@ -1,5 +1,9 @@
+import datetime
+
 import pytz
-from datetime import datetime
+
+from timezone_field.compat import ZoneInfo
+from timezone_field.utils import use_pytz_default
 
 
 def standard(timezones):
@@ -12,11 +16,11 @@ def standard(timezones):
     choices = []
     for tz in timezones:
         tz_str = str(tz)
-        choices.append((tz, tz_str.replace('_', ' ')))
+        choices.append((tz, tz_str.replace("_", " ")))
     return choices
 
 
-def with_gmt_offset(timezones, now=None):
+def with_gmt_offset(timezones, now=None, use_pytz=None):
     """
     Given a list of timezones (either strings of timezone objects),
     return a list of choices with
@@ -25,15 +29,23 @@ def with_gmt_offset(timezones, now=None):
           underscores. For example: "GMT-05:00 America/New York"
         * sorted by their timezone offset
     """
-    now = now or datetime.utcnow()
+    use_pytz = use_pytz_default() if use_pytz is None else use_pytz
+    if use_pytz:
+        utc = pytz.utc
+        timezone_func = pytz.timezone
+    else:
+        utc = ZoneInfo("UTC")
+        timezone_func = ZoneInfo
+    now = now or datetime.datetime.now(utc)
     _choices = []
     for tz in timezones:
         tz_str = str(tz)
-        delta = pytz.timezone(tz_str).utcoffset(now)
+        now_tz = now.astimezone(timezone_func(tz_str))
+        delta = now_tz.replace(tzinfo=utc) - now
         display = "GMT{sign}{gmt_diff} {timezone}".format(
-            sign='+' if delta == abs(delta) else '-',
+            sign="+" if delta == abs(delta) else "-",
             gmt_diff=str(abs(delta)).zfill(8)[:-3],
-            timezone=tz_str.replace('_', ' ')
+            timezone=tz_str.replace("_", " "),
         )
         _choices.append((delta, tz, display))
     _choices.sort(key=lambda x: x[0])
